@@ -20,6 +20,11 @@ from .utils import Reader, load_data, resample_like  # isort:skip  # noqa: E402,
 from .gateway import Gateway  # isort:skip  # noqa: E402, F401
 from .readers import axds, erddap, local  # isort:skip  # noqa: E402
 
+from .vars import (  # isort:skip  # noqa: F401, E402
+    all_variables,
+    check_variables,
+    search_variables,
+)
 
 try:
     from ._version import __version__
